import json
import re
import logging
import requests
from odoo.exceptions import UserError
from odoo import models, fields, api, _
from odoo.exceptions import UserError

_logger = logging.getLogger(__name__)


class Partner(models.Model):
    _name = "res.partner"
    _inherit = ['res.partner', 'pos.load.mixin']

    @api.onchange('name')
    def onchange_name(self):
        if self.name and self._is_dominican_vat(self.name):
            result = self._get_dgii_info_by_rnc(self.name)
            if result and len(result) > 0:
                data = result[0]
                self.name = data.get('nombre', '')
                self.vat = data.get('rnc', '')

    @api.model
    def _load_pos_data_fields(self, config_id):
        rstl = super()._load_pos_data_fields(config_id)
        rstl.append('l10n_do_dgii_tax_payer_type')
        return rstl

    def _get_payer_type(self, vat, name):
        """ Compute the type of partner depending on soft decisions"""
        company_id = self.env["res.company"].search(
            [("id", "=", self.env.user.company_id.id)]
        )
        payer_type = "non_payer"
        vat = str(vat if vat else name)
        if vat.isdigit() and len(vat) == 9:
            if not vat:
                vat = vat
            if name and "MINISTERIO" in name:
                payer_type = "governmental"
            elif name and any(
                [n for n in ("IGLESIA", "ZONA FRANCA") if n in name]
            ):
                payer_type = "special"
            elif vat.startswith("1"):
                payer_type = "taxpayer"
            elif vat.startswith("4"):
                payer_type = "nonprofit"
            else:
                payer_type = "taxpayer"

        elif len(vat) == 11:
            if vat.isdigit():
                if not vat:
                    vat = vat
                payer_type = (
                    "taxpayer"
                    if company_id.l10n_do_default_client == "taxpayer"
                    else "non_payer"
                )
                payer_type = payer_type

        return payer_type

